.. _examples:

========
Examples
========

`dask-examples`_ contains a set of runnable examples:

* The `basic machine learning example`_ gives an overview and many specific
  examples are listed in the table of contents on the main page.
* The `machine learning section`_ gives more examples of using Dask for machine
  learning with other libraries or for particular machine learning use cases.

Dask-ML can be used with XGBoost, PyTorch and TPOT, and can be used for
hyperparameter optimization. These are some of the examples that
`dask-examples`_ includes.

.. _machine learning section: https://examples.dask.org/#machine-learning
.. _dask-examples: https://examples.dask.org
.. _basic machine learning example: https://examples.dask.org/machine-learning.html
